# ucon

[![tests](https://github.com/withtwoemms/ucon/workflows/tests/badge.svg))](https://github.com/withtwoemms/ucon/actions?query=workflow%3Atests)
[![publish](https://github.com/withtwoemms/ucon/workflows/publish/badge.svg)](https://github.com/withtwoemms/ucon/actions?query=workflow%3Apublish)

a tool for dimensional analysis: a "Unit CONverter" :)
